@@ -199,6 +199,7 @@ class _Parser(object):
     def parse(self, expression):
         """Parse a MongoDB expression."""
         if not isinstance(expression, dict):
+            # May raise a KeyError despite the ignore missing key.
             return self._parse_basic_expression(expression)
 
         if len(expression) > 1 and any(key.startswith('$') for key in expression):
@@ -255,6 +256,8 @@ class _Parser(object):
             except KeyError:
                 if self._ignore_missing_keys:
                     yield None
+                else:
+                    raise
 
     def _parse_to_bool(self, expression):
         """Parse a MongoDB expression and then convert it to bool"""
@@ -930,6 +933,25 @@ def _handle_lookup_stage(in_collection, database, options):
     return in_collection
 
 
+def _recursive_get(match, nested_fields):
+    head = match.get(nested_fields[0])
+    remaining_fields = nested_fields[1:]
+    if not remaining_fields:
+        # Final/last field reached.
+        yield head
+        return
+    # More fields to go, must be list, tuple, or dict.
+    if isinstance(head, (list, tuple)):
+        for m in head:
+            # Yield from _recursive_get(m, remaining_fields).
+            for answer in _recursive_get(m, remaining_fields):
+                yield answer
+    elif isinstance(head, dict):
+        # Yield from _recursive_get(head, remaining_fields).
+        for answer in _recursive_get(head, remaining_fields):
+            yield answer
+
+
 def _handle_graph_lookup_stage(in_collection, database, options):
     if not isinstance(options.get('maxDepth', 0), six.integer_types):
         raise OperationFailure(
@@ -952,8 +974,7 @@ def _handle_graph_lookup_stage(in_collection, database, options):
                 "Argument '%s' to $graphLookup must be string" % operator)
         if options[operator].startswith('$'):
             raise OperationFailure("FieldPath field names may not start with '$'")
-        if operator in ('connectFromField', 'as') and \
-                '.' in options[operator]:
+        if operator == 'as' and '.' in options[operator]:
             raise NotImplementedError(
                 "Although '.' is valid in the '%s' "
                 'parameter for the $graphLookup stage of the aggregation '
@@ -987,14 +1008,18 @@ def _handle_graph_lookup_stage(in_collection, database, options):
     for doc in out_doc:
         found_items = set()
         depth = 0
-        result = _parse_expression(start_with, doc)
+        try:
+            result = _parse_expression(start_with, doc)
+        except KeyError:
+            continue
         origin_matches = doc[local_name] = _find_matches_for_depth(result)
         while origin_matches and (max_depth is None or depth < max_depth):
             depth += 1
             newly_discovered_matches = []
             for match in origin_matches:
-                match_target = match.get(connect_from_field)
-                newly_discovered_matches += _find_matches_for_depth(match_target)
+                nested_fields = connect_from_field.split('.')
+                for match_target in _recursive_get(match, nested_fields):
+                    newly_discovered_matches += _find_matches_for_depth(match_target)
             doc[local_name] += newly_discovered_matches
             origin_matches = newly_discovered_matches
     return out_doc
@@ -1271,6 +1296,7 @@ def _handle_project_stage(in_collection, unused_database, options):
             try:
                 out_doc[field] = _parse_expression(value, in_doc, ignore_missing_keys=True)
             except KeyError:
+                # Ignore missing key.
                 pass
     if (method == 'include') == (include_id is not False and include_id is not 0):
         filter_list.append('_id')
