@@ -1,5 +1,7 @@
 import warnings
 
+from mongomock.filtering import filter_applies
+
 from . import CollectionInvalid
 from . import InvalidName
 from . import OperationFailure
@@ -16,6 +18,15 @@ try:
 except ImportError:
     _READ_PREFERENCE_PRIMARY = read_preferences.PRIMARY
 
+_LIST_COLLECTION_FILTER_ALLOWED_OPERATORS = frozenset(['$regex', '$eq', '$ne'])
+
+
+def _verify_list_collection_supported_op(keys):
+    if set(keys) - _LIST_COLLECTION_FILTER_ALLOWED_OPERATORS:
+        raise NotImplementedError(
+            'list collection names filter operator {0} is not implemented yet in mongomock '
+            'allowed operators are {1}'.format(keys, _LIST_COLLECTION_FILTER_ALLOWED_OPERATORS))
+
 
 class Database(object):
 
@@ -41,6 +52,11 @@ class Database(object):
     def __repr__(self):
         return "Database({0}, '{1}')".format(self._client, self.name)
 
+    def __eq__(self, other):
+        if isinstance(other, self.__class__):
+            return self._client == other._client and self.name == other.name
+        return NotImplemented
+
     @property
     def client(self):
         return self._client
@@ -63,10 +79,31 @@ class Database(object):
 
         return self.list_collection_names(session=session)
 
-    def list_collection_names(self, session=None):
+    def list_collection_names(self, filter=None, session=None):
+        """filter: only name field type with eq,ne or regex operator
+
+        session: not supported
+        for supported operator please see _LIST_COLLECTION_FILTER_ALLOWED_OPERATORS
+        """
+        field_name = 'name'
+
         if session:
             raise NotImplementedError('Mongomock does not handle sessions yet')
 
+        if filter:
+            if not filter.get('name'):
+                raise NotImplementedError('list collection {0} might be valid but is not '
+                                          'implemented yet in mongomock'.format(filter))
+
+            filter = {field_name: {'$eq': filter.get(field_name)}} \
+                if isinstance(filter.get(field_name), str) else filter
+
+            _verify_list_collection_supported_op(filter.get(field_name).keys())
+
+            return [name for name in list(self._store._collections)
+                    if filter_applies(filter, {field_name: name}) and
+                    not name.startswith('system.')]
+
         return [
             name for name in self._get_created_collections()
             if not name.startswith('system.')
